========
pyticoop
========


.. image:: https://img.shields.io/pypi/v/pyticoop.svg
        :target: https://pypi.python.org/pypi/pyticoop

.. image:: https://gitlab.com/ticoop/pyticoop/badges/main/pipeline.svg
   :target: https://gitlab.com/ticoop/pyticoop/-/pipelines
   :alt: Pipeline Status

.. image:: https://readthedocs.org/projects/pyticoop/badge/?version=latest
        :target: https://pyticoop.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Composants Python réutilisables.


* Free software: GNU General Public License v3
* Documentation: https://pyticoop.readthedocs.io.


Features
--------

* Dolibarr Module: An abstraction layer to interact with the Dolibarr API, simplifying integration with Dolibarr systems


Deployment
----------

To deploy to PyPI:

1. Create a tag following the format ``vx.x.x`` (e.g., ``v1.2.3``)
2. Push the tag to trigger the deployment pipeline


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage